@@ -1,9 +1,9 @@
 # pylint: disable=missing-docstring
 import json
 
+import jwt
 import pytest
 import responses
-import jwt
 
 from ibm_cloud_sdk_core.authenticators import IAMAuthenticator
 
@@ -41,6 +41,30 @@ def test_iam_authenticator():
     authenticator.set_proxies({'dummy': 'proxies'})
     assert authenticator.token_manager.proxies == {'dummy': 'proxies'}
 
+    authenticator.set_disable_ssl_verification(True)
+    assert authenticator.token_manager.disable_ssl_verification
+
+
+def test_disable_ssl_verification():
+    authenticator = IAMAuthenticator(apikey='my_apikey', disable_ssl_verification=True)
+    assert authenticator.token_manager.disable_ssl_verification is True
+
+    authenticator.set_disable_ssl_verification(False)
+    assert authenticator.token_manager.disable_ssl_verification is False
+
+
+def test_invalid_disable_ssl_verification_type():
+    with pytest.raises(TypeError) as err:
+        authenticator = IAMAuthenticator(apikey='my_apikey', disable_ssl_verification='True')
+    assert str(err.value) == 'disable_ssl_verification must be a bool'
+
+    authenticator = IAMAuthenticator(apikey='my_apikey')
+    assert authenticator.token_manager.disable_ssl_verification is False
+
+    with pytest.raises(TypeError) as err:
+        authenticator.set_disable_ssl_verification('True')
+    assert str(err.value) == 'status must be a bool'
+
 
 def test_iam_authenticator_with_scope():
     authenticator = IAMAuthenticator(apikey='my_apikey', scope='scope1 scope2')
